//@line 4 "/builds/slave/tb-rel-c-beta-l64_rpk_9-000000/l10n/sq/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-l64_rpk_9-000000/l10n/sq/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-l64_rpk_9-000000/l10n/sq/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 12 "/builds/slave/tb-rel-c-beta-l64_rpk_9-000000/l10n/sq/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "sq");

//@line 23 "/builds/slave/tb-rel-c-beta-l64_rpk_9-000000/l10n/sq/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Biznes,Blerës,Çështje,Datëlindje,Dhurata,Furnitorë,Ide,Klientë,Konkurrencë,Leje,Mbledhje,Ndjekje,Personale,Përvjetor,Projekte,Pushime,Festa,Status,Të ndryshme,Të parapëlqyera,Thirrje,Udhëtime");
